---
title: <span class="badge builder"></span> TableFooterOptions
---
# <span class="badge builder"></span> TableFooterOptions

## Constructor

```python
TableFooterOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.TableFooterOptions
```

### <span class="badge object-method"></span> count_rows

```python
def count_rows(count_rows: bool) -> typing.Self
```

### <span class="badge object-method"></span> enable_pagination

```python
def enable_pagination(enable_pagination: bool) -> typing.Self
```

### <span class="badge object-method"></span> fields

```python
def fields(fields: list[str]) -> typing.Self
```

### <span class="badge object-method"></span> reducer

actually 1 value

```python
def reducer(reducer: list[str]) -> typing.Self
```

### <span class="badge object-method"></span> show

```python
def show(show: bool) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [TableFooterOptions](./object-TableFooterOptions.md)
